/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import { withState } from '@dump247/storybook-state';
import * as knobs from '@storybook/addon-knobs/react';
import Header from '../../Header/Header';
import AnueSearch from '../AnueSearch';
import { MobileMenu } from '../../MobileHeader';
import AccountMenu from '../../AccountMenu/AccountMenu';
import AccountMenuStyles from '../../AccountMenu/__stories__/Container.scss';
import defaultNotes from './AnueSearch.md';

const WRAPPER_STYLES = {
  width: '100vw',
  height: '150vh',
  display: 'flex',
  justifyContent: 'flex-start',
  alignItems: 'center',
  flexDirection: 'column',
};

const MOBILE_WRAPPER_STYLES = {
  ...WRAPPER_STYLES,
  backgroundColor: 'rgba(0, 0, 0, 0.5)',
};

const MOBILE_MENU_SEARCH_ICON_WRAPPER = {
  position: 'absolute',
  right: 0,
  top: 0,
  height: '44px',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  zIndex: 5,
};

const stories = storiesOf('AnueSearch', module);

stories.addDecorator(knobs.withKnobs);

stories.add(
  'Desktop',
  withState()(
    withNotes(defaultNotes)(
      withInfo()(() => (
        <div style={WRAPPER_STYLES}>
          <Header
            channel="全站搜尋Bar"
            displayChannelName
            customMenu={<AccountMenu />}
            searchBar={<AnueSearch apiEnv="beta" theme="desktop" />}
          />
        </div>
      ))
    )
  )
);

stories.add(
  'Mobile',
  withState({
    isSearchVisible: false,
  })(
    withNotes(defaultNotes)(
      withInfo()(({ store }) => {
        const handleSearchVisible = visible => {
          store.set({
            isSearchVisible: visible,
          });
        };

        return (
          <div style={MOBILE_WRAPPER_STYLES}>
            <div className={AccountMenuStyles.mobileWrapper} style={{ backgroundColor: '#fff', height: '100vh' }}>
              <header className={AccountMenuStyles.mobileHeader} style={{ borderBottom: '1px solid #eee' }}>
                <MobileMenu />
                <nav className={AccountMenuStyles.mobileLinks}>
                  <a>外匯</a>
                  <a>市場</a>
                  <a>虛擬貨幣</a>
                </nav>
                <div className={AccountMenuStyles.accountWrapper}>
                  <AccountMenu highlight isLogin />
                </div>
                <div
                  style={{
                    ...MOBILE_MENU_SEARCH_ICON_WRAPPER,
                  }}
                />
              </header>
              <div
                style={{
                  ...MOBILE_MENU_SEARCH_ICON_WRAPPER,
                  width: store.state.isSearchVisible ? '100%' : 'auto',
                  maxWidth: 'calc(100% - 35px)',
                }}
              >
                <AnueSearch
                  theme="mobile"
                  onSearchVisibilityChange={handleSearchVisible}
                  shouldDisplayBackIcon
                  apiEnv="beta"
                />
              </div>
            </div>
          </div>
        );
      })
    )
  )
);
