/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import { withState } from '@dump247/storybook-state';
import * as knobs from '@storybook/addon-knobs/react';
import Compare from '../Compare';
import defaultNotes from './Compare.md';

const MOCK_DATA = [
  { id: 'May the force be with you', name: 'May the force be with you - Jedi' },
  { id: 'You complete me', name: 'You complete me - Jerry Maguire' },
  { id: 'Let it go', name: 'Let it go - Lisa' },
  {
    id: 'With great power comes great responsibility',
    name: 'With great power comes great responsibility - Uncle Ben',
  },
];

const stories = [storiesOf('Compare/desktop', module), storiesOf('Compare/mobile', module)];

const WRAPPER_STYLES = {
  width: '100vw',
  height: '100vh',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
};
const LOG_STYLES = { maxWidth: '50%', margin: '0 auto' };

stories.forEach((story, idx) => {
  const isMobileStory = idx === 1;

  story.addDecorator(knobs.withKnobs);

  story.add(
    'Add or delete the item from KNOBS',
    withState({ items: isMobileStory ? MOCK_DATA.slice(0, 2) : MOCK_DATA, clickCompareCbReturn: null })(
      withNotes(defaultNotes)(
        withInfo()(({ store }) => {
          const _items = store.state.items.slice(
            0,
            knobs.number('Number of the items to compare', 1, { max: isMobileStory ? 2 : 4, min: 0, step: 1 })
          );

          return (
            <div style={WRAPPER_STYLES}>
              <p style={LOG_STYLES}>
                {store.state.clickCompareCbReturn && `The compare items => ${store.state.clickCompareCbReturn}`}
              </p>
              <Compare
                items={_items}
                ctaCb={items => {
                  store.set({ clickCompareCbReturn: JSON.stringify(items) });
                }}
                clickItemCloseCb={() => {}}
                isMobile={isMobileStory}
              />
            </div>
          );
        })
      )
    )
  );

  story.add(
    'Delete the item by clicking the cross icon',
    withState({ items: isMobileStory ? MOCK_DATA.slice(0, 2) : MOCK_DATA, clickCompareCbReturn: null })(
      withNotes(defaultNotes)(
        withInfo()(({ store }) => {
          return (
            <div style={WRAPPER_STYLES}>
              <p style={LOG_STYLES}>
                {store.state.clickCompareCbReturn && `The compare items  => ${store.state.clickCompareCbReturn}`}
              </p>
              <Compare
                items={store.state.items}
                ctaCb={items => {
                  store.set({ clickCompareCbReturn: JSON.stringify(items) });
                }}
                clickItemCloseCb={id => {
                  const items = store.state.items.filter(item => item.id !== id);

                  store.set({ items });
                }}
                isMobile={isMobileStory}
              />
            </div>
          );
        })
      )
    )
  );
});
