import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import LoadingSkeleton from '../LoadingSkeleton/LoadingSkeleton';
import CarouselOld, { DOT_POSITION } from '../Carousel/CarouselOld';
import gaDataset from '../../utils/gaDataset';
import settings from './config/settings.json';
import styles from './LogoWallCarousel.scss';

const cx = classNames.bind(styles);

// Dynamically Loading Local Images with ReactJS
// https://stackoverflow.com/questions/41947474/dynamically-loading-local-images-with-reactjs?rq=1
const images = require.context('../../assets/logo-wall', true);

export const LOGO_WALL_TYPE = {
  HOMEPAGE: 'homepage',
  NEWS: 'news',
  FOREX: 'forex',
  US_STOCK: 'usStock',
};

class LogoWallCarouselOld extends React.PureComponent {
  static propTypes = {
    width: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
    height: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
    delay: PropTypes.number,
    type: PropTypes.oneOf(Object.values(LOGO_WALL_TYPE)),
    dataPrefix: PropTypes.arrayOf(PropTypes.string),
  };

  static defaultProps = {
    width: 334,
    height: 230,
    delay: 10000,
    type: LOGO_WALL_TYPE.HOMEPAGE,
    dataPrefix: ['data-global-ga'],
  };

  constructor(props) {
    super(props);

    const { type } = this.props;

    this.sources = settings[type] || [Array(4).fill(0), Array(4).fill(0), Array(4).fill(0)];
  }

  loadingSkeleton = (
    <div className={cx('slide__loading')}>
      <div className={cx('slide__loading--left')}>
        <div className={cx('slide__loading--left-image')}>
          <LoadingSkeleton />
        </div>
      </div>
      <div className={cx('slide__loading--right')}>
        <div className={cx('slide__loading--right-title')}>
          <LoadingSkeleton />
        </div>
        <div className={cx('slide__loading--right-subtitle')}>
          <LoadingSkeleton />
        </div>
      </div>
    </div>
  );

  renderItem = items => {
    const { dataPrefix } = this.props;

    return items.map((setting, index) => {
      return setting ? (
        <a
          key={`logo_wall_item_${index + 1}`}
          className={cx('slide__item')}
          href={setting.url}
          target="_blank"
          rel="noopener noreferrer"
          {...gaDataset({ dataPrefix, category: 'LogoWall', action: 'click', label: setting.title })}
          title={setting.title}
        >
          <div className={cx('slide__item--left')}>
            <img src={images(setting.icon)} alt={setting.name} />
          </div>
          <div className={cx('slide__item--right')}>
            <h5>{setting.title}</h5>
            <p>{setting.subtitle}</p>
          </div>
        </a>
      ) : (
        this.loadingSkeleton
      );
    });
  };

  render() {
    const { width, height, delay } = this.props;
    const containerWidth = width.toString().includes('%') ? width : `${width}px`;
    let containerHeight = height;

    if (!height.toString().includes('%')) {
      const magicHeight = height + 12 + 7 + 2;

      containerHeight = `${magicHeight}px`;
    }

    return (
      <div style={{ width: containerWidth, height: containerHeight }}>
        <div className={cx('slide')}>
          <CarouselOld width={width} height={height} speed={delay} dotPosition={DOT_POSITION.FIXED}>
            {this.sources &&
              this.sources.map((items, index) => (
                <div key={`logo_wall_${index + 1}`} className={cx('slide--wrapper')}>
                  {this.renderItem(items)}
                </div>
              ))}
          </CarouselOld>
        </div>
      </div>
    );
  }
}

export default LogoWallCarouselOld;
